<template>
  <a-card
    :bordered='false'
    title='危险防控'
  >
    <!-- 查询区域 -->
    <div class='table-page-search-wrapper'>
      <a-form
        layout='inline'
        @keyup.enter.native='searchQuery'
      >
        <a-row :gutter='24'>

          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <a-form-item label='危险源编码'>
              <j-input
                placeholder='请输入危险源编码'
                v-model='queryParam.num'
              ></j-input>
            </a-form-item>
          </a-col>
          <template>
            <a-col
              :xl='6'
              :lg='7'
              :md='8'
              :sm='24'
            >
              <a-form-item label='危险源'>
                <j-input
                  placeholder='请输入危险源'
                  v-model='queryParam.name'
                ></j-input>
              </a-form-item>
            </a-col>
          </template>
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <span
              style='float: left;overflow: hidden;'
              class='table-page-search-submitButtons'
            >
              <a-button
                type='primary'
                @click='searchQuery'
                icon='search'
              >查询</a-button>
              <a-button
                type='primary'
                @click='searchReset'
                icon='reload'
                style='margin-left: 8px'
              >重置</a-button>
              <!--              <a @click="handleToggleSearch" style="margin-left: 8px">-->
              <!--                {{ toggleSearchStatus ? '收起' : '展开' }}-->
              <!--                <a-icon :type="toggleSearchStatus ? 'up' : 'down'"/>-->
              <!--              </a>-->
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class='table-operator'>
      <a-button
        @click='handleAdd'
        type='primary'
        icon='plus'
      >新增</a-button>
      <a-button
        type='primary'
        icon='download'
        @click="handleExportXls('危险防控')"
      >导出</a-button>
      <a-upload
        name='file'
        :showUploadList='false'
        :multiple='false'
        :headers='tokenHeader'
        :action='importExcelUrl'
        @change='handleImportExcel'
      >
        <a-button
          type='primary'
          icon='import'
        >导入</a-button>
      </a-upload>

      <a-dropdown v-if='selectedRowKeys.length > 0'>
        <a-menu slot='overlay'>
          <a-menu-item
            key='1'
            @click='batchDel'
          >
            <a-icon type='delete' />
            删除
          </a-menu-item>
        </a-menu>
        <a-button style='margin-left: 8px'> 批量操作
          <a-icon type='down' />
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div
        class='ant-alert ant-alert-info'
        style='margin-bottom: 16px;'
      >
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a
          style='margin-left: 24px'
          @click='onClearSelected'
        >清空</a>
      </div>

      <a-table
        ref='table'
        size='middle'
        :scroll='{x:true}'
        bordered
        rowKey='id'
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        :rowSelection='{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}'
        class='j-table-force-nowrap'
        @change='handleTableChange'
      >
        <template
          slot="description"
          slot-scope="text"
        >
          <a-tooltip
            placement="top"
            :title="text"
            trigger="hover"
          >
            <div>
              <template slot="title"> </template>
              <p style="cusor:pointer; overflow: hidden; white-space: nowrap; text-overflow: ellipsis; width: 130px;">{{ text }}</p>
            </div>
          </a-tooltip>
        </template>
        <template
          slot="num"
          slot-scope="text"
        >
          <a-tooltip
            placement="top"
            :title="text"
            trigger="hover"
          >
            <div>
              <template slot="title"> </template>
              <p style="cusor:pointer; overflow: hidden; white-space: nowrap; text-overflow: ellipsis; width: 130px;">{{ text }}</p>
            </div>
          </a-tooltip>
        </template>
        <template
          slot="measure"
          slot-scope="text"
        >
          <a-tooltip
            placement="top"
            :title="text"
            trigger="hover"
          >
            <div>
              <template slot="title"> </template>
              <p style="cusor:pointer; overflow: hidden; white-space: nowrap; text-overflow: ellipsis; width: 130px;">{{ text }}</p>
            </div>
          </a-tooltip>
        </template>

        <template
          slot='htmlSlot'
          slot-scope='text'
        >
          <div v-html='text'></div>
        </template>
        <template
          slot='imgSlot'
          slot-scope='text,record'
        >
          <span
            v-if='!text'
            style='font-size: 12px;font-style: italic;'
          >无图片</span>
          <img
            v-else
            :src='getImgView(text)'
            :preview='record.id'
            height='25px'
            alt=''
            style='max-width:80px;font-size: 12px;font-style: italic;'
          />
        </template>
        <template
          slot='fileSlot'
          slot-scope='text'
        >
          <span
            v-if='!text'
            style='font-size: 12px;font-style: italic;'
          >无文件</span>
          <a-button
            v-else
            :ghost='true'
            type='primary'
            icon='download'
            size='small'
            @click='downloadFile(text)'
          >
            下载
          </a-button>
        </template>

        <span
          slot='action'
          slot-scope='text, record'
        >
          <a @click='handleEdit(record)'>编辑</a>

          <a-divider type='vertical' />
          <a-dropdown>
            <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
            <a-menu slot='overlay'>
              <a-menu-item>
                <a @click='handleDetail(record)'>详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm
                  title='确定删除吗?'
                  @confirm='() => handleDelete(record.id)'
                >
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>

    <risk-prevention-modal
      ref='modalForm'
      @ok='modalFormOk'
    ></risk-prevention-modal>
  </a-card>
</template>

<script>

import '@assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import RiskPreventionModal from './modules/riskPrevention/RiskPreventionModal'

export default {
  name: 'RiskPreventionList',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    RiskPreventionModal
  },
  data() {
    return {
      description: '危险防控管理页面',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: ' 危险源编码',
          align: 'center',
          dataIndex: 'num',
          // scopedSlots: { customRender: 'num' },
          // ellipsis: true,
        },
        {
          title: '危险源名称',
          align: 'center',
          dataIndex: 'name'
        },
        {
          title: '危险描述',
          align: 'center',
          dataIndex: 'description',
          // scopedSlots: { customRender: 'description' },
          // width: 100,
          // ellipsis: true,
        },
        {
          title: '防控措施',
          align: 'center',
          dataIndex: 'measure',
          // scopedSlots: { customRender: 'measure' },
          // width: 100,
          // ellipsis: true,
        },
        {
          title: '创建人',
          align: 'center',
          dataIndex: 'createBy'
        },
        {
          title: '创建日期',
          align: 'center',
          dataIndex: 'createTime'
        },
        {
          title: '更新人',
          align: 'center',
          dataIndex: 'updateBy'
        },
        {
          title: '更新日期',
          align: 'center',
          dataIndex: 'updateTime'
        },
        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark'
        },

        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          width: 147,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: '/eam/riskPrevention/list',
        delete: '/eam/riskPrevention/delete',
        deleteBatch: '/eam/riskPrevention/deleteBatch',
        exportXlsUrl: '/eam/riskPrevention/exportXls',
        importExcelUrl: '/eam/riskPrevention/importExcel'

      },
      dictOptions: {},
      superFieldList: []
    }
  },
  created() {
    this.getSuperFieldList()
  },
  computed: {
    importExcelUrl: function () {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  methods: {
    initDictConfig() {
    },
    getSuperFieldList() {
      let fieldList = []
      fieldList.push({ type: 'string', value: 'num', text: '危险源编码', dictCode: '' })
      fieldList.push({ type: 'string', value: 'name', text: '危险名称', dictCode: '' })
      fieldList.push({ type: 'string', value: 'description', text: '危险描述', dictCode: '' })
      fieldList.push({ type: 'string', value: 'measure', text: '防控措施', dictCode: '' })
      fieldList.push({ type: 'string', value: 'remark', text: '备注', dictCode: '' })
      fieldList.push({ type: 'string', value: 'createBy', text: '创建人', dictCode: '' })
      fieldList.push({ type: 'datetime', value: 'createTime', text: '创建日期' })
      fieldList.push({ type: 'string', value: 'updateBy', text: '更新人', dictCode: '' })
      fieldList.push({ type: 'datetime', value: 'updateTime', text: '更新日期' })
      this.superFieldList = fieldList
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>